@@ -33,8 +33,22 @@ from typing import (
 from disspy.reaction import DisEmoji
 from disspy import errors
 
+__all__: tuple = (
+    "Component",
+    "Button",
+    "ButtonStyle",
+    "SelectMenuOption",
+    "SelectMenu",
+    "TextInput",
+    "TextInputStyle",
+    "ActionRow"
+)
+
 
 class Component:
+    """
+    Class for creating components
+    """
     def __init__(self, ctype, custom_id=None, label=None, style=None, url=None,
                  options=None, min_values=None, max_values=None,
                  min_length=None, max_length=None, placeholder=None, required=None) -> NoReturn:
@@ -69,6 +83,9 @@ class Component:
 
 
 class Button(Component):
+    """
+    Class for creating buttons in Action Row
+    """
     def __init__(self, label: Text, style: Optional[int] = None, url: Optional[str] = None,
                  custom_id: Optional[Text] = None, ) -> NoReturn:
         if not style == 5 and url and not custom_id or style == 5 and not url and custom_id:
@@ -80,6 +97,9 @@ class Button(Component):
 
 
 class ButtonStyle:
+    """
+    Button styles from official discord docs
+    """
     BLUE = 1
     GREY = 2
     GREEN = 3
@@ -88,14 +108,23 @@ class ButtonStyle:
 
 
 class SelectMenuOption:
-    def __init__(self, label: str, value: str, description: str, emoji: Union[DisEmoji, str], default: bool = False):
+    """
+    Class for creating options in select menus
+    """
+    def __init__(self, label: str, value: str, description: str, emoji: Union[DisEmoji, str],
+                 default: bool = False) -> NoReturn:
         self.label = label
         self.value = value
         self.description = description
         self.emoji = emoji
         self.default = default
 
-    def json(self):
+    def json(self) -> Dict:
+        """json()
+
+        Returns:
+            Dict: Json data of option
+        """
         if isinstance(self.emoji, DisEmoji):
             if self.emoji.unicode:
                 e_j = {
@@ -123,25 +152,37 @@ class SelectMenuOption:
 
 
 class SelectMenu(Component):
-    def __init__(self, custom_id, options: list[SelectMenuOption], placeholder, min_values, max_values):
+    """
+    Class for creating select menus in Action Row
+    """
+    def __init__(self, custom_id: str, options: list[SelectMenuOption], placeholder: str,
+                 min_values: int, max_values: int) -> NoReturn:
         oj = []
 
         for i in options:
             oj.append(i.json())
 
-        super().__init__(3, custom_id=custom_id, options=oj, min_values=min_values, max_values=max_values,
-                         placeholder=placeholder)
+        super().__init__(3, custom_id=custom_id, options=oj, min_values=min_values,
+                         max_values=max_values, placeholder=placeholder)
 
 
 class TextInput(Component):
-    def __init__(self, label, min_length, max_length, placeholder, required=False, style=None):
+    """
+    Class for creating text inputs in Action Row
+    """
+    def __init__(self, label, min_length, max_length, placeholder,
+                 required=False, style=None) -> NoReturn:
         if style is None:  # Default
             style = 1  # Short
-        super().__init__(4, custom_id=label, style=style, label=label, min_length=min_length, max_length=max_length,
+        super().__init__(4, custom_id=label, style=style, label=label,
+                         min_length=min_length, max_length=max_length,
                          placeholder=placeholder, required=required)
 
 
 class TextInputStyle:
+    """
+    Text input styles from official discord docs
+    """
     SHORT = 1
     PARAGRAPH = 2
 
@@ -179,6 +220,9 @@ class _ComponentGenerator:
 
 
 class ActionRow:
+    """
+    Class for creating action rows in messages
+    """
     def __init__(self, bot) -> NoReturn:
         self.json = [{
             "type": 1,
@@ -187,10 +231,14 @@ class ActionRow:
         self._b = bot
 
     def add(self, c: Component):
+        """add()
+
+        Args:
+            c (Component): Component
+        """
         def wrapper(func):
             self.json[0]["components"].append(_ComponentGenerator(c))
-            from disspy.client import DisBot
-            self._b: DisBot = self._b
+            self._b = self._b
             self._b.api.comsevs[c.custom_id] = func
 
         return wrapper
